# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [2.1.0](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@2.0.0...@visa/charts-python@2.1.0) (2023-06-16)

### Bug Fixes

- bump and fix charts-python package ([64ebe55](https://github.com/visa/visa-chart-components/commit/64ebe55f2ddefaf1994e62f752ffd0d95edde026))

### Features

- utils-dev and charts-python bumps ([35b5657](https://github.com/visa/visa-chart-components/commit/35b565778dde994337f60284bf179b73976cc78b))

# [2.0.0](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@1.1.0...@visa/charts-python@2.0.0) (2023-02-01)

### chore

- d3-color bump to 3.1.0 and resolutions ([dd9a2fb](https://github.com/visa/visa-chart-components/commit/dd9a2fb369c44bab6607acb5229ceb656dce5561))

### BREAKING CHANGES

- d3-color bump to 3.1.0, IE11 support no longer maintained. If you need to support IE11, you should stick with the previous release.

# [1.1.0](https://github.com/visa/visa-chart-components/compare/@visa/charts-python@1.0.0...@visa/charts-python@1.1.0) (2023-01-13)

### Features

- feat bump charts-python bundle for dataKeyNames prop and more ([e9586b9](https://github.com/visa/visa-chart-components/commit/e9586b9ad6412b3b7563f197a7a40e136fa8de99))

# 1.0.0 (2022-07-28)

### chore

- initial deployment of charts-python package ([af68e9f](https://github.com/visa/visa-chart-components/commit/af68e9fc88253bb4c40391ae6b78441aca570e76))

### BREAKING CHANGES

- initial deployment of charts-python package

Co-authored-by: Chris DeMartini <74268675+chris-demartini@users.noreply.github.com>
